@@ -150,11 +150,9 @@ almanah_import_export_dialog_new (AlmanahStorageManager *storage_manager, gboole
 	AlmanahImportExportDialog *import_export_dialog;
 	AlmanahImportExportDialogPrivate *priv;
 	GError *error = NULL;
-	const gchar *interface_filename = almanah_get_interface_filename ();
 	const gchar *object_names[] = {
 		"almanah_ied_mode_store",
 		"almanah_import_export_dialog",
-		"almanah_ui_manager", /* HACK: work around bgo#672789 */
 		NULL
 	};
 
@@ -162,10 +160,13 @@ almanah_import_export_dialog_new (AlmanahStorageManager *storage_manager, gboole
 
 	builder = gtk_builder_new ();
 
-	if (gtk_builder_add_objects_from_file (builder, interface_filename, (gchar**) object_names, &error) == FALSE) {
+	if (gtk_builder_add_objects_from_resource (builder, "/org/gnome/Almanah/ui/almanah.ui", (gchar**) object_names, &error) == 0) {
 		/* Show an error */
-		GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-		                                            _("UI file \"%s\" could not be loaded"), interface_filename);
+		GtkWidget *dialog = gtk_message_dialog_new (NULL,
+							    GTK_DIALOG_MODAL,
+							    GTK_MESSAGE_ERROR,
+							    GTK_BUTTONS_OK,
+		                                            _("UI data could not be loaded"));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", error->message);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
@@ -204,8 +205,10 @@ almanah_import_export_dialog_new (AlmanahStorageManager *storage_manager, gboole
 	/* Set the window title */
 	gtk_window_set_title (GTK_WINDOW (import_export_dialog), (import == TRUE) ? _("Import Entries") : _("Export Entries"));
 
-	/* Set the button label */
-	gtk_button_set_label (GTK_BUTTON (priv->import_export_button), (import == TRUE) ? _("_Import") : _("_Export"));
+	/* Set the button label. */
+	gtk_button_set_label (GTK_BUTTON (priv->import_export_button),
+	                      /* Translators: These are verbs. */
+	                      (import == TRUE) ? C_("Dialog button", "_Import") : C_("Dialog button", "_Export"));
 
 	/* Populate the mode combo box */
 	if (import == TRUE)
@@ -454,22 +457,23 @@ almanah_import_results_dialog_new (void)
 	AlmanahImportResultsDialog *results_dialog;
 	AlmanahImportResultsDialogPrivate *priv;
 	GError *error = NULL;
-	const gchar *interface_filename = almanah_get_interface_filename ();
 	const gchar *object_names[] = {
 		"almanah_ird_view_store",
 		"almanah_ird_results_store",
 		"almanah_ird_filtered_results_store",
 		"almanah_import_results_dialog",
-		"almanah_ui_manager", /* HACK: work around bgo#672789 */
 		NULL
 	};
 
 	builder = gtk_builder_new ();
 
-	if (gtk_builder_add_objects_from_file (builder, interface_filename, (gchar**) object_names, &error) == FALSE) {
+	if (gtk_builder_add_objects_from_resource (builder, "/org/gnome/Almanah/ui/almanah.ui", (gchar**) object_names, &error) == 0) {
 		/* Show an error */
-		GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-		                                            _("UI file \"%s\" could not be loaded"), interface_filename);
+		GtkWidget *dialog = gtk_message_dialog_new (NULL,
+							    GTK_DIALOG_MODAL,
+							    GTK_MESSAGE_ERROR,
+							    GTK_BUTTONS_OK,
+		                                            _("UI data could not be loaded"));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", error->message);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
