@@ -22,7 +22,6 @@
 
 #include "calendar-button.h"
 #include "calendar.h"
-#include "calendar-window.h"
 #include "interface.h"
 
 /* This enum allows to know the reason why the calendar date has been changed */
@@ -36,6 +35,7 @@ enum {
 
 enum {
 	DAY_SELECTED_SIGNAL,
+	SELECT_DATE_CLICKED_SIGNAL,
 	LAST_SIGNAL
 };
 
@@ -46,7 +46,6 @@ enum {
 static guint calendar_button_signals[LAST_SIGNAL] = { 0 };
 
 struct _AlmanahCalendarButtonPrivate {
-	GtkWidget *label;
 	GtkWidget *dock;
 	guchar user_event;
 	AlmanahCalendar *calendar;
@@ -59,13 +58,15 @@ static void almanah_calendar_button_get_property (GObject *object, guint propert
 static void almanah_calendar_button_set_property (GObject *object, guint property_id, const GValue *value, GParamSpec *pspec);
 static void almanah_calendar_button_finalize (GObject *object);
 
-static void almanah_calendar_button_dock_hiden (GtkWidget *dock, AlmanahCalendarButton *self);
+static void almanah_calendar_button_dock_closed (GtkWidget *dock, AlmanahCalendarButton *self);
 
 static void almanah_calendar_button_toggled (GtkToggleButton *togglebutton);
 static void almanah_calendar_button_day_selected_cb (GtkCalendar *calendar, AlmanahCalendarButton *self);
 static void almanah_calendar_button_month_changed_cb (GtkCalendar *calendar, AlmanahCalendarButton *self);
-static gboolean almanah_calendar_button_today_press_cb (GtkWidget *widget, GdkEvent *event, AlmanahCalendarButton *self);
-static gboolean almanah_calendar_button_select_date_press_cb (GtkWidget *widget, GdkEvent *event, AlmanahCalendarButton *self);
+static gboolean almanah_calendar_button_today_press_cb         (GtkWidget *widget, GdkEvent *event, AlmanahCalendarButton *self);
+static void     almanah_calendar_button_today_clicked_cb       (GtkButton *button, gpointer user_data);
+static void     almanah_calendar_button_select_date_clicked_cb (GtkButton *button, gpointer user_data);
+static gboolean almanah_calendar_button_select_date_press_cb   (GtkWidget *widget, GdkEvent *event, AlmanahCalendarButton *self);
 
 static void dock_position_func (AlmanahCalendarButton *self, gint *x, gint *y);
 
@@ -104,16 +105,27 @@ almanah_calendar_button_class_init (AlmanahCalendarButtonClass *klass)
 								     NULL, NULL,
 								     NULL,
 								     G_TYPE_NONE, 0);
+
+	/**
+	 * AlmanahCalendarButton::select-date-clicked:
+	 * @calendar_button: the object which received the signal.
+	 *
+	 * Emitted when the user clicks the "select date" button in the dock window.
+	 */
+	calendar_button_signals[SELECT_DATE_CLICKED_SIGNAL] = g_signal_new ("select-date-clicked",
+									    G_OBJECT_CLASS_TYPE (gobject_class),
+									    G_SIGNAL_RUN_FIRST,
+									    G_STRUCT_OFFSET (AlmanahCalendarButtonClass, select_date_clicked),
+									    NULL, NULL,
+									    NULL,
+									    G_TYPE_NONE, 0);
 }
 
 static void
 almanah_calendar_button_init (AlmanahCalendarButton *self)
 {
-	GtkWidget *arrow;
-	GtkBox *main_box;
 	GtkBuilder *builder;
 	GError *error = NULL;
-	const gchar *interface_filename = almanah_get_interface_filename ();
 	const gchar *object_names[] = {
 		"almanah_calendar_window",
 		NULL
@@ -124,20 +136,10 @@ almanah_calendar_button_init (AlmanahCalendarButton *self)
 
 	gtk_button_set_focus_on_click (GTK_BUTTON (self), TRUE);
 
-	/* The button elements */
-	self->priv->label = gtk_label_new (NULL);
-
-	arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_NONE);
-
-	main_box = GTK_BOX (gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6));
-	gtk_box_pack_start (main_box, self->priv->label, TRUE, TRUE, 0);
-	gtk_box_pack_start (main_box, arrow, FALSE, TRUE, 0);
-	gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (main_box));
-
 	/* Calendar dock window from the UI file */
 	builder = gtk_builder_new ();
-	if (gtk_builder_add_objects_from_file (builder, interface_filename, (gchar **) object_names, &error) == FALSE) {
-		g_warning (_("UI file \"%s\" could not be loaded: %s"), interface_filename, error->message);
+	if (gtk_builder_add_objects_from_resource (builder, "/org/gnome/Almanah/ui/almanah.ui", (gchar **) object_names, &error) == 0) {
+		g_warning (_("UI data could not be loaded: %s"), error->message);
 		g_error_free (error);
 		g_object_unref (builder);
 
@@ -152,9 +154,9 @@ almanah_calendar_button_init (AlmanahCalendarButton *self)
 
 		return;
 	}
-	gtk_window_set_type_hint (GTK_WINDOW (self->priv->dock), GDK_WINDOW_TYPE_HINT_DROPDOWN_MENU);
+	gtk_popover_set_relative_to (GTK_POPOVER (self->priv->dock), GTK_WIDGET (self));
 
-	g_signal_connect (self->priv->dock, "hide", G_CALLBACK (almanah_calendar_button_dock_hiden), self);
+	g_signal_connect (self->priv->dock, "hide", G_CALLBACK (almanah_calendar_button_dock_closed), self);
 
 	/* The calendar widget */
 	self->priv->calendar = ALMANAH_CALENDAR (gtk_builder_get_object (builder, "almanah_cw_calendar"));
@@ -164,11 +166,13 @@ almanah_calendar_button_init (AlmanahCalendarButton *self)
 
 	/* Today button */
 	self->priv->today_button = GTK_WIDGET (gtk_builder_get_object (builder, "almanah_cw_today_button"));
+	g_signal_connect (self->priv->today_button, "clicked", G_CALLBACK (almanah_calendar_button_today_clicked_cb), self);
 	g_signal_connect (self->priv->today_button, "button-press-event", G_CALLBACK (almanah_calendar_button_today_press_cb), self);
 
 	/* Select a day button */
 	/* @TODO: No the button press event, instead the 'activate' action funcion (if not, the select day window dosn't showed... */
 	self->priv->select_date_button = GTK_WIDGET (gtk_builder_get_object (builder, "almanah_cw_select_date_button"));
+	g_signal_connect (self->priv->select_date_button, "clicked", G_CALLBACK (almanah_calendar_button_select_date_clicked_cb), self);
 	g_signal_connect (self->priv->select_date_button, "button-press-event", G_CALLBACK (almanah_calendar_button_select_date_press_cb), self);
 
 	g_object_unref (builder);
@@ -216,67 +220,8 @@ almanah_calendar_button_finalize (GObject *object)
 	G_OBJECT_CLASS (almanah_calendar_button_parent_class)->finalize (object);
 }
 
-/**
- * Calculate the window position
- */
 static void
-dock_position_func (AlmanahCalendarButton *self, gint *x, gint *y)
-{
-	GdkScreen *screen;
-	GdkRectangle monitor;
-	GtkAllocation allocation;
-	GtkRequisition dock_req;
-	gint new_x, new_y, monitor_num;
-	AlmanahCalendarWindow *calendar_window = ALMANAH_CALENDAR_WINDOW (self->priv->dock);
-
-	/* Get the screen and monitor geometry */
-	screen = gtk_widget_get_screen (GTK_WIDGET (self));
-	monitor_num = gdk_screen_get_monitor_at_window (screen, gtk_widget_get_window (GTK_WIDGET (self)));
-	if (monitor_num < 0)
-		monitor_num = 0;
-	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
-
-	/* Get the AlmanahCalendarButton position */
-	gtk_widget_get_allocation (GTK_WIDGET (self), &allocation);
-	gdk_window_get_origin (gtk_widget_get_window (GTK_WIDGET (self)), &new_x, &new_y);
-	/* The dock window starting position is over the calendar button widget */
-	new_x += allocation.x;
-	new_y += allocation.y;
-
-	gtk_widget_get_preferred_size (GTK_WIDGET (calendar_window), &dock_req, NULL);
-	if (new_x + dock_req.width > monitor.x + monitor.width) {
-		/* Move the required pixels to the left if the dock don't showed complety
-		 * in the screen
-		 */
-		new_x -= (new_x + dock_req.width) - (monitor.x + monitor.width);
-	}
-
-	if ((new_y + allocation.height + dock_req.height) <= monitor.y + monitor.height) {
-		/*The dock window height isn't bigger than the monitor size */
-		new_y += allocation.height;
-	} else if (new_y - dock_req.height >= monitor.y) {
-		/* If the dock window height can't showed complety in the monitor,
-		 * and the dock height isn't to bigg to show on top the calendar button
-		 * move it on top of the calendar button
-		 */
-		new_y -= dock_req.height;
-	} else if (monitor.y + monitor.height - (new_y + allocation.height) > new_y) {
-		/* in other case, we show under the calendar button if the space is enought */
-		new_y += allocation.height;
-	} else {
-		/* we need to put the dock in somewhere... even the monitor is to small */
-		new_y -= dock_req.height;
-	}
-
-	/* Put the dock window in the correct screen */
-	gtk_window_set_screen (GTK_WINDOW (calendar_window), screen);
-
-	*x = new_x;
-	*y = new_y;
-}
-
-static void
-almanah_calendar_button_dock_hiden (GtkWidget *dock, AlmanahCalendarButton *self)
+almanah_calendar_button_dock_closed (GtkWidget *dock, AlmanahCalendarButton *self)
 {
 	/* Reset the calendar user event and toggle off the button */
 	ALMANAH_CALENDAR_BUTTON (self)->priv->user_event = NONE_EVENT;
@@ -286,32 +231,22 @@ almanah_calendar_button_dock_hiden (GtkWidget *dock, AlmanahCalendarButton *self
 static void
 almanah_calendar_button_toggled (GtkToggleButton *togglebutton)
 {
-	gint x, y;
 	AlmanahCalendarButton *self;
 
 	self = ALMANAH_CALENDAR_BUTTON (togglebutton);
 	if (gtk_toggle_button_get_active (togglebutton)) {
 		/* Show the dock */
-		dock_position_func (self, &x, &y);
-		gtk_window_move (GTK_WINDOW (self->priv->dock), x, y);
-		almanah_calendar_window_popup (ALMANAH_CALENDAR_WINDOW (self->priv->dock));
+		gtk_widget_show_all (GTK_WIDGET (self->priv->dock));
 	}
 }
 
 static void
 almanah_calendar_button_day_selected_cb (GtkCalendar *calendar, AlmanahCalendarButton *self)
 {
-	GDate calendar_date;
-	gchar calendar_string[100];
-
-	almanah_calendar_get_date (self->priv->calendar, &calendar_date);
-	/* Translators: This is a strftime()-format string for the date displayed at the top of the main window. */
-	g_date_strftime (calendar_string, sizeof (calendar_string), _("%A, %e %B %Y"), &calendar_date);
-	gtk_label_set_text (GTK_LABEL (self->priv->label), calendar_string);
 	if (self->priv->user_event < DAY_EVENT) {
 		/* Only hide the dock window when the user has clicked in a calendar day */
 		self->priv->user_event = DAY_EVENT;
-		almanah_calendar_window_popdown (ALMANAH_CALENDAR_WINDOW (self->priv->dock));
+		gtk_widget_hide (GTK_WIDGET (self->priv->dock));
 	}
 
 	self->priv->user_event = NONE_EVENT;
@@ -339,6 +274,14 @@ almanah_calendar_button_today_press_cb (GtkWidget *widget, GdkEvent *event, Alma
 	return FALSE;
 }
 
+static void
+almanah_calendar_button_today_clicked_cb (__attribute__ ((unused)) GtkButton *button, gpointer user_data)
+{
+	AlmanahCalendarButton *self = ALMANAH_CALENDAR_BUTTON (user_data);
+
+	almanah_calendar_button_select_today (self);
+}
+
 static gboolean
 almanah_calendar_button_select_date_press_cb (GtkWidget *widget, GdkEvent *event, AlmanahCalendarButton *self)
 {
@@ -347,6 +290,14 @@ almanah_calendar_button_select_date_press_cb (GtkWidget *widget, GdkEvent *event
 	return FALSE;
 }
 
+static void
+almanah_calendar_button_select_date_clicked_cb (__attribute__ ((unused)) GtkButton *button, gpointer user_data)
+{
+	AlmanahCalendarButton *self = ALMANAH_CALENDAR_BUTTON (user_data);
+
+	g_signal_emit (self, calendar_button_signals[SELECT_DATE_CLICKED_SIGNAL], 0);
+}
+
 GtkWidget *
 almanah_calendar_button_new (AlmanahStorageManager *storage_manager)
 {
@@ -369,28 +320,6 @@ almanah_calendar_button_set_storage_manager (AlmanahCalendarButton *self, Almana
 	}
 }
 
-void
-almanah_calendar_button_set_today_action (AlmanahCalendarButton *self, GtkAction *action)
-{
-	g_return_if_fail (ALMANAH_IS_CALENDAR_BUTTON (self));
-	g_return_if_fail (GTK_IS_ACTION (action));
-
-	if (GTK_IS_BUTTON (self->priv->today_button)) {
-		gtk_activatable_set_related_action (GTK_ACTIVATABLE (self->priv->today_button), action);
-	}
-}
-
-void
-almanah_calendar_button_set_select_date_action (AlmanahCalendarButton *self, GtkAction *action)
-{
-	g_return_if_fail (ALMANAH_IS_CALENDAR_BUTTON (self));
-	g_return_if_fail (GTK_IS_ACTION (action));
-
-	if (GTK_IS_BUTTON (self->priv->select_date_button)) {
-		gtk_activatable_set_related_action (GTK_ACTIVATABLE (self->priv->select_date_button), action);
-	}
-}
-
 void
 almanah_calendar_button_select_date (AlmanahCalendarButton *self, GDate *date)
 {
@@ -414,5 +343,16 @@ almanah_calendar_button_popdown (AlmanahCalendarButton *self)
 {
 	g_return_if_fail (ALMANAH_IS_CALENDAR_BUTTON (self));
 
-	almanah_calendar_window_popdown (ALMANAH_CALENDAR_WINDOW (self->priv->dock));
+	gtk_widget_hide (GTK_WIDGET (self->priv->dock));
+}
+
+void
+almanah_calendar_button_select_today (AlmanahCalendarButton *self)
+{
+	GDate current_date;
+
+	g_return_if_fail (ALMANAH_IS_CALENDAR_BUTTON (self));
+
+	g_date_set_time_t (&current_date, time (NULL));
+	almanah_calendar_button_select_date (self, &current_date);
 }
